---
title: Lighting module
summary: Provides the main interface to the OpenWebNet lighting system.
---

The Lighting module provides the main interface to the OpenWebNet lighting system.

::: pyown.items.lighting.base.WhatLight
    options:
        show_inheritance_diagram: true

::: pyown.items.lighting.base.LightEvents
    options:
        show_inheritance_diagram: true

::: pyown.items.lighting.base.BaseLight
    options:
        show_inheritance_diagram: true

::: pyown.items.lighting.light.Light
    options:
        show_inheritance_diagram: true

::: pyown.items.lighting.dimmer.Dimmer
    options:
        show_inheritance_diagram: true
